from __future__ import print_function
from os import urandom
from binascii import b2a_hex


def main():
    key = b2a_hex(urandom(32))
    print('/key/swarm/psk/1.0.0/')
    print('/base16/')
    print(key)


if __name__ == "__main__":
    main()



#!/usr/bin/env python

from setuptools import setup
from piskg import __version__

long_description = open('README.rst').read()
desc = """Python IPFS Swarm Key Generator"""

setup(
    name='piskg',
    version=__version__,
    url='https://github.com/machawk1/piskg',
    download_url="https://github.com/machawk1/piskg",
    author='Mat Kelly',
    author_email='mkelly@cs.odu.edu',
    description=desc,
    packages=['piskg'],
    license='MIT',
    long_description=long_description,
    provides=[
        'piskg'
    ],
    entry_points="""
        [console_scripts]
        piskg = piskg.__main__:main
    """,
    package_data={},
    keywords='ipfs keygen',
    classifiers=[
        'Topic :: Utilities',
    ]
)

# Publish to pypi: rm -rf dist; python setup.py sdist bdist_wheel; twine upload dist/*
